==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/InstantRPAdditionalDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.InstantRPAdditionalDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Instant recovery point additional details.
 * @property azureBackupRGNamePrefix Azure backup resource group name prefix.
 * @property azureBackupRGNameSuffix Azure backup resource group name suffix.
 */
public data class InstantRPAdditionalDetailsArgs(
    public val azureBackupRGNamePrefix: Output<String>? = null,
    public val azureBackupRGNameSuffix: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.InstantRPAdditionalDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.InstantRPAdditionalDetailsArgs =
        com.pulumi.azurenative.workloads.inputs.InstantRPAdditionalDetailsArgs.builder()
            .azureBackupRGNamePrefix(azureBackupRGNamePrefix?.applyValue({ args0 -> args0 }))
            .azureBackupRGNameSuffix(azureBackupRGNameSuffix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InstantRPAdditionalDetailsArgs].
 */
@PulumiTagMarker
public class InstantRPAdditionalDetailsArgsBuilder internal constructor() {
    private var azureBackupRGNamePrefix: Output<String>? = null

    private var azureBackupRGNameSuffix: Output<String>? = null

    /**
     * @param value Azure backup resource group name prefix.
     */
    @JvmName("vnlhifhguiyqaflp")
    public suspend fun azureBackupRGNamePrefix(`value`: Output<String>) {
        this.azureBackupRGNamePrefix = value
    }

    /**
     * @param value Azure backup resource group name suffix.
     */
    @JvmName("atstncmbpvstlici")
    public suspend fun azureBackupRGNameSuffix(`value`: Output<String>) {
        this.azureBackupRGNameSuffix = value
    }

    /**
     * @param value Azure backup resource group name prefix.
     */
    @JvmName("gcebkkntepdwjrsb")
    public suspend fun azureBackupRGNamePrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureBackupRGNamePrefix = mapped
    }

    /**
     * @param value Azure backup resource group name suffix.
     */
    @JvmName("bjeetqbiwcetnfmv")
    public suspend fun azureBackupRGNameSuffix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureBackupRGNameSuffix = mapped
    }

    internal fun build(): InstantRPAdditionalDetailsArgs = InstantRPAdditionalDetailsArgs(
        azureBackupRGNamePrefix = azureBackupRGNamePrefix,
        azureBackupRGNameSuffix = azureBackupRGNameSuffix,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/InstantRPAdditionalDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.InstantRPAdditionalDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Instant recovery point additional details.
 * @property azureBackupRGNamePrefix Azure backup resource group name prefix.
 * @property azureBackupRGNameSuffix Azure backup resource group name suffix.
 */
public data class InstantRPAdditionalDetailsArgs(
    public val azureBackupRGNamePrefix: Output<String>? = null,
    public val azureBackupRGNameSuffix: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.InstantRPAdditionalDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.InstantRPAdditionalDetailsArgs =
        com.pulumi.azurenative.workloads.inputs.InstantRPAdditionalDetailsArgs.builder()
            .azureBackupRGNamePrefix(azureBackupRGNamePrefix?.applyValue({ args0 -> args0 }))
            .azureBackupRGNameSuffix(azureBackupRGNameSuffix?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [InstantRPAdditionalDetailsArgs].
 */
@PulumiTagMarker
public class InstantRPAdditionalDetailsArgsBuilder internal constructor() {
    private var azureBackupRGNamePrefix: Output<String>? = null

    private var azureBackupRGNameSuffix: Output<String>? = null

    /**
     * @param value Azure backup resource group name prefix.
     */
    @JvmName("rhidaemhhqrpndne")
    public suspend fun azureBackupRGNamePrefix(`value`: Output<String>) {
        this.azureBackupRGNamePrefix = value
    }

    /**
     * @param value Azure backup resource group name suffix.
     */
    @JvmName("vbsixwcimmuevulm")
    public suspend fun azureBackupRGNameSuffix(`value`: Output<String>) {
        this.azureBackupRGNameSuffix = value
    }

    /**
     * @param value Azure backup resource group name prefix.
     */
    @JvmName("edkwdossdffcterr")
    public suspend fun azureBackupRGNamePrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureBackupRGNamePrefix = mapped
    }

    /**
     * @param value Azure backup resource group name suffix.
     */
    @JvmName("vafotlxnruhcyrvv")
    public suspend fun azureBackupRGNameSuffix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.azureBackupRGNameSuffix = mapped
    }

    internal fun build(): InstantRPAdditionalDetailsArgs = InstantRPAdditionalDetailsArgs(
        azureBackupRGNamePrefix = azureBackupRGNamePrefix,
        azureBackupRGNameSuffix = azureBackupRGNameSuffix,
    )
}
